@@ -494,14 +494,18 @@ class ExperimentSection():
         Change an indexing object (slice or int) from using 1-based indexing to using 0-based indexing.
 
         """
-        try:
-            if isinstance(item, slice):
+        if isinstance(item, slice):
+            try:
                 return slice(self._convert_index(item.start), self._convert_index(item.stop), item.step)
-            else:
-                return self._convert_index(item)
+            except IndexError:
+                raise IndexError('Use 1-based indexing with ExperimentSection instances')
 
-        except IndexError:
-            raise IndexError('Use 1-based indexing with ExperimentSection instances')
+        # Tuples will be converted when they come through as individual indices.
+        elif isinstance(item, tuple):
+            return item
+
+        else:
+            return self._convert_index(item)
 
     @staticmethod
     def _convert_index(idx):
@@ -524,6 +528,13 @@ class ExperimentSection():
 
         if isinstance(item, slice):
             return list(itertools.islice(self._children, *item.indices(len(self))))
+
+        elif isinstance(item, tuple):
+            section = self
+            for idx in item:
+                section = section[idx]
+            return section
+
         else:
             return self._children[item]
 
